CREATE PROCEDURE stp_InventoryByTypeByMonth
	 @Year int
AS

-- Find the last inventory date for each month.
SELECT 
	MAX(InventoryFact.DateOfInventory) AS EOMDate
INTO
	#EndOfMonth
FROM 
	InventoryFact
WHERE     
	YEAR(InventoryFact.DateOfInventory) = @Year
GROUP BY 
	MONTH(InventoryFact.DateOfInventory)

-- Find the inventory on those dates.
SELECT     
	SUM(InventoryFact.InventoryLevel / 1000) AS InventoryLevel, 
	DimProductType.ProductTypeName, 
	DATENAME(mm, InventoryFact.DateOfInventory) AS MonthName
FROM         
	InventoryFact 
INNER JOIN
	DimProduct ON InventoryFact.ProductCode = DimProduct.ProductCode 
INNER JOIN
	DimProductSubtype ON DimProduct.ProductSubtypeCode = DimProductSubtype.ProductSubtypeCode 
INNER JOIN
	DimProductType ON DimProductSubtype.ProductTypeCode = DimProductType.ProductTypeCode
WHERE     
	InventoryFact.DateOfInventory IN (SELECT EOMDate FROM #EndOfMonth)
GROUP BY 
	DimProductType.ProductTypeName, DATENAME(mm, InventoryFact.DateOfInventory), MONTH(InventoryFact.DateOfInventory)
ORDER BY 
	MONTH(InventoryFact.DateOfInventory), ProductTypeName

